Module models

Module models 

Modules

agent_skills
agents
catalogs
credentials
external_locations
functions
labels
model_versions
policies
providers
recipients
registered_models
schemas
shares
staging_tables
tables
tags
temporary_credentials
volumes

Macros

resource_name
Creates a nested column name whose field names are all simple resource names (containing only alphanumeric characters and underscores), delimited by dots. This macro is provided as a convenience for the common case where the caller knows the column name contains only simple field names and that splitting by periods is safe:

Structs

Agent
An agent registered in Unity Catalog.
AgentSkill
An agent skill registered in Unity Catalog.
Catalog
A catalog is a root-level namespace that contains schemas.
Column
Credential
A credential used to access external data sources or services.
ErrorResponse
ExternalLocation
Function
A User-Defined Function (UDF) registered under a catalog + schema hierarchy.
ModelVersion
A model version under a registered model.
PolicyInfo
A row-filter or column-mask policy bound to principals and scoped to a securable.
Provider
A provider represents an organization sharing data with this metastore.
Recipient
RegisteredModel
A registered model within the three-level namespace (catalog.schema.model).
ResourceName
A (possibly nested) resource name: a path of field-name segments.
Schema
A schema is a namespace within a catalog that contains tables.
Share
StagingTable
A staging table is a transient reservation created while provisioning a Unity Catalog managed table.
Table
TagPolicy
A governed tag definition (tag policy).
Volume

Enums

AssociationLabel
ObjectLabel
Discriminant label for each resource type.
Resource
All resource types managed by the service.
ResourceIdent
Resource that a policy can authorize.
ResourceRef
A reference to a resource, by id, by name, or unspecified.

Statics

EMPTY_RESOURCE_NAME
A shared, empty ResourceName (a zero-segment path).

Traits

ResourceExt

Type Aliases

Object
Project-specific alias for resource_store::Object with our generated ObjectLabel.
PropertyMap