pub struct CreateAgentRequest {
pub catalog_name: String,
pub schema_name: String,
pub name: String,
pub invocation_protocol: EnumValue<InvocationProtocol>,
pub endpoint: String,
pub description: Option<String>,
pub capabilities: Vec<String>,
pub input_schema: Option<String>,
pub comment: Option<String>,
/* private fields */
}Expand description
Create a new agent.
Fields
catalog_name: StringThe identifier of the catalog.
Field 1: catalog_name
schema_name: StringThe identifier of the schema.
Field 2: schema_name
name: StringThe identifier of the agent.
Field 3: name
invocation_protocol: EnumValue<InvocationProtocol>The protocol a recipient uses to invoke the agent.
Field 4: invocation_protocol
endpoint: StringThe agent’s invocation endpoint URL.
Field 5: endpoint
description: Option<String>An LLM-readable description of what the agent does and the inputs it expects.
Field 6: description
capabilities: Vec<String>Capability identifiers advertised by the agent.
Field 7: capabilities
input_schema: Option<String>A JSON Schema (encoded as a JSON string) describing the expected input.
Field 8: input_schema
comment: Option<String>User-provided free-form text description.
Field 9: comment
Implementations
Sourceimpl CreateAgentRequest
impl CreateAgentRequest
Sourcepub fn with_description(self, value: impl Into<String>) -> Self
pub fn with_description(self, value: impl Into<String>) -> Self
Sets Self::description to Some(value), consuming and returning self.
Sourcepub fn with_input_schema(self, value: impl Into<String>) -> Self
pub fn with_input_schema(self, value: impl Into<String>) -> Self
Sets Self::input_schema to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.