pub struct AzureServicePrincipal {
pub directory_id: String,
pub application_id: String,
pub credential: Option<Credential>,
}Expand description
The Azure service principal configuration.
Fields
directory_id: StringThe directory ID corresponding to the Azure Active Directory (AAD) tenant of the application.
application_id: StringThe application ID of the application registration within the referenced AAD tenant.
credential: Option<Credential>Trait Implementations
Sourceimpl Clone for AzureServicePrincipal
impl Clone for AzureServicePrincipal
Sourcefn clone(&self) -> AzureServicePrincipal
fn clone(&self) -> AzureServicePrincipal
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AzureServicePrincipal
impl Debug for AzureServicePrincipal
Sourceimpl Default for AzureServicePrincipal
impl Default for AzureServicePrincipal
impl<'de> Deserialize<'de> for AzureServicePrincipal
impl<'de> Deserialize<'de> for AzureServicePrincipal
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AzureServicePrincipal
Sourceimpl Hash for AzureServicePrincipal
impl Hash for AzureServicePrincipal
Sourceimpl Message for AzureServicePrincipal
impl Message for AzureServicePrincipal
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for AzureServicePrincipal
impl PartialEq for AzureServicePrincipal
impl Serialize for AzureServicePrincipal
impl Serialize for AzureServicePrincipal
impl StructuralPartialEq for AzureServicePrincipal