pub struct CreateCredentialRequest {
pub name: String,
pub purpose: i32,
pub comment: Option<String>,
pub read_only: Option<bool>,
pub skip_validation: Option<bool>,
pub azure_service_principal: Option<AzureServicePrincipal>,
pub azure_managed_identity: Option<AzureManagedIdentity>,
pub azure_storage_key: Option<AzureStorageKey>,
pub aws_iam_role: Option<AwsIamRoleConfig>,
pub databricks_gcp_service_account: Option<DatabricksGcpServiceAccount>,
}Expand description
Create a new credential.
Fields
name: StringThe credential name. The name must be unique among storage and service credentials within the metastore.
purpose: i32Indicates the purpose of the credential.
comment: Option<String>Comment associated with the credential.
read_only: Option<bool>Whether the credential is usable only for read operations. Only applicable when purpose is STORAGE.
skip_validation: Option<bool>Optional. Supplying true to this argument skips validation of the created set of credentials.
azure_service_principal: Option<AzureServicePrincipal>The Azure service principal configuration.
azure_managed_identity: Option<AzureManagedIdentity>The Azure managed identity configuration.
azure_storage_key: Option<AzureStorageKey>The Azure storage key configuration.
aws_iam_role: Option<AwsIamRoleConfig>The AWS IAM role configuration.
databricks_gcp_service_account: Option<DatabricksGcpServiceAccount>The Databricks managed GCP service account configuration.
Implementations
Sourceimpl CreateCredentialRequest
impl CreateCredentialRequest
Sourcepub fn purpose(&self) -> Purpose
pub fn purpose(&self) -> Purpose
Returns the enum value of purpose, or the default if the field is set to an invalid enum value.
Sourcepub fn set_purpose(&mut self, value: Purpose)
pub fn set_purpose(&mut self, value: Purpose)
Sets purpose to the provided enum value.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn read_only(&self) -> bool
pub fn read_only(&self) -> bool
Returns the value of read_only, or the default value if read_only is unset.
Sourcepub fn skip_validation(&self) -> bool
pub fn skip_validation(&self) -> bool
Returns the value of skip_validation, or the default value if skip_validation is unset.