pub struct DatabricksGcpServiceAccount {
pub credential_id: Option<String>,
pub email: Option<String>,
pub private_key_id: Option<String>,
}Expand description
The Databricks managed GCP service account configuration.
Fields
credential_id: Option<String>The Databricks internal ID that represents this managed identity.
email: Option<String>The email of the service account.
private_key_id: Option<String>The ID that represents the private key for this Service Account.
Implementations
Sourceimpl DatabricksGcpServiceAccount
impl DatabricksGcpServiceAccount
Sourcepub fn credential_id(&self) -> &str
pub fn credential_id(&self) -> &str
Returns the value of credential_id, or the default value if credential_id is unset.
Sourcepub fn email(&self) -> &str
pub fn email(&self) -> &str
Returns the value of email, or the default value if email is unset.
Sourcepub fn private_key_id(&self) -> &str
pub fn private_key_id(&self) -> &str
Returns the value of private_key_id, or the default value if private_key_id is unset.