pub struct ListCredentialsRequest {
pub purpose: Option<EnumValue<Purpose>>,
pub max_results: Option<i32>,
pub page_token: Option<String>,
/* private fields */
}Fields
purpose: Option<EnumValue<Purpose>>Return only credentials for the specified purpose.
Field 1: purpose
max_results: Option<i32>The maximum number of results per page that should be returned.
Field 2: max_results
page_token: Option<String>Opaque pagination token to go to next page based on previous query.
Field 3: page_token
Implementations
Sourceimpl ListCredentialsRequest
impl ListCredentialsRequest
Sourcepub fn with_purpose(self, value: impl Into<EnumValue<Purpose>>) -> Self
pub fn with_purpose(self, value: impl Into<EnumValue<Purpose>>) -> Self
Sets Self::purpose to Some(value), consuming and returning self.
Sourcepub fn with_max_results(self, value: i32) -> Self
pub fn with_max_results(self, value: i32) -> Self
Sets Self::max_results to Some(value), consuming and returning self.
Sourcepub fn with_page_token(self, value: impl Into<String>) -> Self
pub fn with_page_token(self, value: impl Into<String>) -> Self
Sets Self::page_token to Some(value), consuming and returning self.