pub struct UpdateCredentialRequest {
pub name: String,
pub new_name: Option<String>,
pub comment: Option<String>,
pub read_only: Option<bool>,
pub owner: Option<String>,
pub skip_validation: Option<bool>,
pub force: Option<bool>,
pub azure_service_principal: Option<AzureServicePrincipal>,
pub azure_managed_identity: Option<AzureManagedIdentity>,
pub azure_storage_key: Option<AzureStorageKey>,
pub aws_iam_role: Option<AwsIamRoleConfig>,
pub databricks_gcp_service_account: Option<DatabricksGcpServiceAccount>,
}Expand description
Update a credential.
Fields
name: StringName of credential.
new_name: Option<String>New name of the credential.
comment: Option<String>Comment associated with the credential.
read_only: Option<bool>Whether the credential is usable only for read operations. Only applicable when purpose is STORAGE.
owner: Option<String>Username of current owner of credential.
skip_validation: Option<bool>Supply true to this argument to skip validation of the updated credential.
force: Option<bool>Force an update even if there are dependent services (when purpose is SERVICE) or dependent external locations and external tables (when purpose is STORAGE).
azure_service_principal: Option<AzureServicePrincipal>The Azure service principal configuration.
azure_managed_identity: Option<AzureManagedIdentity>The Azure managed identity configuration.
azure_storage_key: Option<AzureStorageKey>The Azure storage key configuration.
aws_iam_role: Option<AwsIamRoleConfig>The AWS IAM role configuration.
databricks_gcp_service_account: Option<DatabricksGcpServiceAccount>The Databricks managed GCP service account configuration.
Implementations
Sourceimpl UpdateCredentialRequest
impl UpdateCredentialRequest
Sourcepub fn new_name(&self) -> &str
pub fn new_name(&self) -> &str
Returns the value of new_name, or the default value if new_name is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn read_only(&self) -> bool
pub fn read_only(&self) -> bool
Returns the value of read_only, or the default value if read_only is unset.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn skip_validation(&self) -> bool
pub fn skip_validation(&self) -> bool
Returns the value of skip_validation, or the default value if skip_validation is unset.