pub struct CreateExternalLocationRequest {
pub name: String,
pub url: String,
pub credential_name: String,
pub read_only: Option<bool>,
pub comment: Option<String>,
pub skip_validation: Option<bool>,
}Expand description
Create a new external location
Fields
name: StringName of external location.
url: StringPath URL of the external location.
credential_name: StringName of the storage credential used with this location.
read_only: Option<bool>Indicates whether the external location is read-only.
comment: Option<String>User-provided free-form text description.
skip_validation: Option<bool>Skips validation of the storage credential associated with the external location.
Implementations
Sourceimpl CreateExternalLocationRequest
impl CreateExternalLocationRequest
Sourcepub fn read_only(&self) -> bool
pub fn read_only(&self) -> bool
Returns the value of read_only, or the default value if read_only is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn skip_validation(&self) -> bool
pub fn skip_validation(&self) -> bool
Returns the value of skip_validation, or the default value if skip_validation is unset.