#[repr(i32)]pub enum RoutineBody {
Unspecified = 0,
Sql = 1,
External = 2,
}Expand description
Determines whether the function body is interpreted as SQL or as an external function.
Variants
Unspecified = 0
Sql = 1
The function is defined in SQL.
External = 2
The function is defined externally.
Implementations
Sourceimpl RoutineBody
impl RoutineBody
Sourceimpl RoutineBody
impl RoutineBody
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.