pub struct Function {Show 26 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub full_name: String,
pub data_type: String,
pub full_data_type: String,
pub input_params: MessageField<FunctionParameterInfos>,
pub return_params: Option<String>,
pub routine_body_language: Option<String>,
pub routine_definition: Option<String>,
pub routine_dependencies: Option<String>,
pub parameter_style: EnumValue<ParameterStyle>,
pub is_deterministic: bool,
pub sql_data_access: EnumValue<SqlDataAccess>,
pub is_null_call: bool,
pub security_type: EnumValue<SecurityType>,
pub specific_name: Option<String>,
pub routine_body: EnumValue<RoutineBody>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub owner: Option<String>,
pub function_id: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
/* private fields */
}Expand description
A User-Defined Function (UDF) registered under a catalog + schema hierarchy.
Fields
name: StringName of function, relative to parent schema.
Field 1: name
catalog_name: StringName of parent catalog.
Field 2: catalog_name
schema_name: StringName of parent schema.
Field 3: schema_name
full_name: StringThe three-level (fully qualified) name of the function.
Format: catalog_name.schema_name.function_name
Field 4: full_name
data_type: StringFull data type specification of the return type of the function.
Field 5: data_type
full_data_type: StringFull data type specification as SQL/catalogString text.
Field 6: full_data_type
input_params: MessageField<FunctionParameterInfos>The array of function parameter infos.
Field 7: input_params
return_params: Option<String>The return type of the function in JSON format.
Field 8: return_params
routine_body_language: Option<String>The language of the function routine body.
Field 9: routine_body_language
routine_definition: Option<String>Function body.
Field 10: routine_definition
routine_dependencies: Option<String>Function dependencies (in JSON form).
Field 11: routine_dependencies
parameter_style: EnumValue<ParameterStyle>The parameter-passing style.
Field 12: parameter_style
is_deterministic: boolIndicates whether the function is deterministic.
Field 13: is_deterministic
sql_data_access: EnumValue<SqlDataAccess>SQL data access information.
Field 14: sql_data_access
is_null_call: boolIndicates whether the function is null-calling.
Field 15: is_null_call
security_type: EnumValue<SecurityType>The security type of the function.
Field 16: security_type
specific_name: Option<String>The type of the function (SCALAR or TABLE).
Field 17: specific_name
routine_body: EnumValue<RoutineBody>The routine body.
Field 18: routine_body
comment: Option<String>User-provided free-form text description.
Field 19: comment
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Field 20: properties
owner: Option<String>Username of current owner of the function.
Field 21: owner
function_id: Option<String>Unique identifier for the function.
Field 22: function_id
created_at: Option<i64>Time at which this function was created, in epoch milliseconds.
Field 1000: created_at
created_by: Option<String>Username of function creator.
Field 1001: created_by
updated_at: Option<i64>Time at which this function was last updated, in epoch milliseconds.
Field 1002: updated_at
updated_by: Option<String>Username of user who last modified the function.
Field 1003: updated_by
Implementations
Sourceimpl Function
impl Function
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Function
impl Function
Sourcepub fn with_return_params(self, value: impl Into<String>) -> Self
pub fn with_return_params(self, value: impl Into<String>) -> Self
Sets Self::return_params to Some(value), consuming and returning self.
Sourcepub fn with_routine_body_language(self, value: impl Into<String>) -> Self
pub fn with_routine_body_language(self, value: impl Into<String>) -> Self
Sets Self::routine_body_language to Some(value), consuming and returning self.
Sourcepub fn with_routine_definition(self, value: impl Into<String>) -> Self
pub fn with_routine_definition(self, value: impl Into<String>) -> Self
Sets Self::routine_definition to Some(value), consuming and returning self.
Sourcepub fn with_routine_dependencies(self, value: impl Into<String>) -> Self
pub fn with_routine_dependencies(self, value: impl Into<String>) -> Self
Sets Self::routine_dependencies to Some(value), consuming and returning self.
Sourcepub fn with_specific_name(self, value: impl Into<String>) -> Self
pub fn with_specific_name(self, value: impl Into<String>) -> Self
Sets Self::specific_name to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_function_id(self, value: impl Into<String>) -> Self
pub fn with_function_id(self, value: impl Into<String>) -> Self
Sets Self::function_id to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.