pub struct FunctionParameterInfo {
pub name: String,
pub type_text: String,
pub type_json: Option<String>,
pub type_name: i32,
pub type_precision: Option<i32>,
pub type_scale: Option<i32>,
pub type_interval_type: Option<String>,
pub position: Option<i32>,
pub parameter_mode: i32,
pub parameter_type: i32,
pub parameter_default: Option<String>,
pub comment: Option<String>,
}Expand description
Information about a single function parameter.
Fields
name: StringName of parameter.
type_text: StringFull data type specification as SQL/catalogString text.
type_json: Option<String>Full data type specification, JSON-serialized.
type_name: i32Data type name.
type_precision: Option<i32>Digits of precision; required for DecimalTypes.
type_scale: Option<i32>Digits to right of decimal; required for DecimalTypes.
type_interval_type: Option<String>Format of IntervalType.
position: Option<i32>Ordinal position of column (starting at position 0).
parameter_mode: i32The mode of the function parameter.
parameter_type: i32The type of function parameter.
parameter_default: Option<String>Default value of the parameter.
comment: Option<String>User-provided free-form text description.
Implementations
Sourceimpl FunctionParameterInfo
impl FunctionParameterInfo
Sourcepub fn type_json(&self) -> &str
pub fn type_json(&self) -> &str
Returns the value of type_json, or the default value if type_json is unset.
Sourcepub fn type_name(&self) -> ColumnTypeName
pub fn type_name(&self) -> ColumnTypeName
Returns the enum value of type_name, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type_name(&mut self, value: ColumnTypeName)
pub fn set_type_name(&mut self, value: ColumnTypeName)
Sets type_name to the provided enum value.
Sourcepub fn type_precision(&self) -> i32
pub fn type_precision(&self) -> i32
Returns the value of type_precision, or the default value if type_precision is unset.
Sourcepub fn type_scale(&self) -> i32
pub fn type_scale(&self) -> i32
Returns the value of type_scale, or the default value if type_scale is unset.
Sourcepub fn type_interval_type(&self) -> &str
pub fn type_interval_type(&self) -> &str
Returns the value of type_interval_type, or the default value if type_interval_type is unset.
Sourcepub fn position(&self) -> i32
pub fn position(&self) -> i32
Returns the value of position, or the default value if position is unset.
Sourcepub fn parameter_mode(&self) -> ParameterMode
pub fn parameter_mode(&self) -> ParameterMode
Returns the enum value of parameter_mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_parameter_mode(&mut self, value: ParameterMode)
pub fn set_parameter_mode(&mut self, value: ParameterMode)
Sets parameter_mode to the provided enum value.
Sourcepub fn parameter_type(&self) -> FunctionParameterType
pub fn parameter_type(&self) -> FunctionParameterType
Returns the enum value of parameter_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_parameter_type(&mut self, value: FunctionParameterType)
pub fn set_parameter_type(&mut self, value: FunctionParameterType)
Sets parameter_type to the provided enum value.
Sourcepub fn parameter_default(&self) -> &str
pub fn parameter_default(&self) -> &str
Returns the value of parameter_default, or the default value if parameter_default is unset.