pub struct ListFunctionsRequest {
pub catalog_name: String,
pub schema_name: String,
pub max_results: Option<i32>,
pub page_token: Option<String>,
pub include_browse: Option<bool>,
/* private fields */
}Expand description
List functions in a schema
Fields
catalog_name: StringName of parent catalog for functions of interest.
Field 1: catalog_name
schema_name: StringParent schema of functions.
Field 2: schema_name
max_results: Option<i32>The maximum number of results per page that should be returned.
Field 3: max_results
page_token: Option<String>Opaque pagination token to go to next page based on previous query.
Field 4: page_token
include_browse: Option<bool>Whether to include functions in the response for which the principal can only access selective metadata for.
Field 5: include_browse
Implementations
Sourceimpl ListFunctionsRequest
impl ListFunctionsRequest
Sourcepub fn with_max_results(self, value: i32) -> Self
pub fn with_max_results(self, value: i32) -> Self
Sets Self::max_results to Some(value), consuming and returning self.
Sourcepub fn with_page_token(self, value: impl Into<String>) -> Self
pub fn with_page_token(self, value: impl Into<String>) -> Self
Sets Self::page_token to Some(value), consuming and returning self.
Sourcepub fn with_include_browse(self, value: bool) -> Self
pub fn with_include_browse(self, value: bool) -> Self
Sets Self::include_browse to Some(value), consuming and returning self.