pub struct CreateModelVersionRequest {
pub model_name: String,
pub catalog_name: String,
pub schema_name: String,
pub source: String,
pub run_id: Option<String>,
pub comment: Option<String>,
/* private fields */
}Expand description
Create a new model version.
Fields
model_name: StringName of the parent registered model, relative to parent schema.
Field 1: model_name
catalog_name: StringName of parent catalog.
Field 2: catalog_name
schema_name: StringName of parent schema.
Field 3: schema_name
source: StringURI indicating the location of the source artifacts (e.g. an MLflow run artifact path) used to create the model version.
Field 4: source
run_id: Option<String>The run id used by the ML package that generated this model.
Field 5: run_id
comment: Option<String>User-provided free-form text description.
Field 6: comment
Implementations
Sourceimpl CreateModelVersionRequest
impl CreateModelVersionRequest
Sourcepub fn with_run_id(self, value: impl Into<String>) -> Self
pub fn with_run_id(self, value: impl Into<String>) -> Self
Sets Self::run_id to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.