pub struct GetModelVersionRequest {
pub full_name: String,
pub version: i64,
pub include_browse: Option<bool>,
/* private fields */
}Expand description
Get a model version.
Fields
full_name: StringThe full three-level name of the parent registered model (catalog.schema.model).
Field 1: full_name
version: i64The integer version number of the model version.
Field 2: version
include_browse: Option<bool>Whether to include model versions in the response for which the principal can only access selective metadata for.
Field 3: include_browse
Implementations
Sourceimpl GetModelVersionRequest
impl GetModelVersionRequest
Sourcepub fn with_include_browse(self, value: bool) -> Self
pub fn with_include_browse(self, value: bool) -> Self
Sets Self::include_browse to Some(value), consuming and returning self.