pub struct CreateProviderRequest {
pub name: String,
pub authentication_type: i32,
pub owner: Option<String>,
pub comment: Option<String>,
pub recipient_profile_str: Option<String>,
pub properties: HashMap<String, String>,
}Expand description
Creates a new provider
Fields
name: StringName of the provider.
authentication_type: i32The delta sharing authentication type.
owner: Option<String>Username of the provider owner.
comment: Option<String>Description about the provider.
recipient_profile_str: Option<String>The recipient profile (credential file contents) used to connect to the sharing server, required for TOKEN authentication.
properties: HashMap<String, String>Provider properties as map of string key-value pairs.
Implementations
Sourceimpl CreateProviderRequest
impl CreateProviderRequest
Sourcepub fn authentication_type(&self) -> ProviderAuthenticationType
pub fn authentication_type(&self) -> ProviderAuthenticationType
Returns the enum value of authentication_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_authentication_type(&mut self, value: ProviderAuthenticationType)
pub fn set_authentication_type(&mut self, value: ProviderAuthenticationType)
Sets authentication_type to the provided enum value.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn recipient_profile_str(&self) -> &str
pub fn recipient_profile_str(&self) -> &str
Returns the value of recipient_profile_str, or the default value if recipient_profile_str is unset.