pub struct CreateRecipientRequest {
pub name: String,
pub authentication_type: i32,
pub owner: String,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub expiration_time: Option<i64>,
}Expand description
Creates a new recipient
Fields
name: StringName of the recipient.
authentication_type: i32The delta sharing authentication type.
owner: StringUsername of the recipient owner.
comment: Option<String>Description about the recipient.
properties: HashMap<String, String>Recipient properties as map of string key-value pairs.
When provided in update request, the specified properties will override the existing properties. To add and remove properties, one would need to perform a read-modify-write.
expiration_time: Option<i64>Expiration timestamp of the token, in epoch milliseconds.
Implementations
Sourceimpl CreateRecipientRequest
impl CreateRecipientRequest
Sourcepub fn authentication_type(&self) -> AuthenticationType
pub fn authentication_type(&self) -> AuthenticationType
Returns the enum value of authentication_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_authentication_type(&mut self, value: AuthenticationType)
pub fn set_authentication_type(&mut self, value: AuthenticationType)
Sets authentication_type to the provided enum value.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn expiration_time(&self) -> i64
pub fn expiration_time(&self) -> i64
Returns the value of expiration_time, or the default value if expiration_time is unset.