pub struct UpdateRecipientRequest {
pub name: String,
pub new_name: Option<String>,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub expiration_time: Option<i64>,
/* private fields */
}Expand description
Update a recipient
Fields
name: StringName of the recipient.
Field 1: name
new_name: Option<String>New name for the recipient
Field 2: new_name
owner: Option<String>Username of the recipient owner.
Field 3: owner
comment: Option<String>Description about the recipient.
Field 4: comment
properties: HashMap<String, String>Recipient properties as map of string key-value pairs.
When provided in update request, the specified properties will override the existing properties. To add and remove properties, one would need to perform a read-modify-write.
Field 5: properties
expiration_time: Option<i64>Expiration timestamp of the token, in epoch milliseconds.
Field 6: expiration_time
Implementations
Sourceimpl UpdateRecipientRequest
impl UpdateRecipientRequest
Sourcepub fn with_new_name(self, value: impl Into<String>) -> Self
pub fn with_new_name(self, value: impl Into<String>) -> Self
Sets Self::new_name to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_expiration_time(self, value: i64) -> Self
pub fn with_expiration_time(self, value: i64) -> Self
Sets Self::expiration_time to Some(value), consuming and returning self.