pub struct GetRegisteredModelRequest {
pub full_name: String,
pub include_browse: Option<bool>,
/* private fields */
}Expand description
Get a registered model.
Fields
full_name: StringThe fully-qualified name of the registered model (three-level name: catalog.schema.model).
Field 1: full_name
include_browse: Option<bool>Whether to include registered models in the response for which the principal can only access selective metadata for.
Field 2: include_browse
Implementations
Sourceimpl GetRegisteredModelRequest
impl GetRegisteredModelRequest
Sourcepub fn with_include_browse(self, value: bool) -> Self
pub fn with_include_browse(self, value: bool) -> Self
Sets Self::include_browse to Some(value), consuming and returning self.