RegisteredModelView

Struct RegisteredModelView 

pub struct RegisteredModelView<'a> {
Show 15 fields pub name: &'a str, pub catalog_name: &'a str, pub schema_name: &'a str, pub full_name: &'a str, pub storage_location: Option<&'a str>, pub owner: Option<&'a str>, pub comment: Option<&'a str>, pub id: Option<&'a str>, pub created_at: Option<i64>, pub created_by: Option<&'a str>, pub updated_at: Option<i64>, pub updated_by: Option<&'a str>, pub metastore_id: Option<&'a str>, pub browse_only: Option<bool>, pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}
A registered model within the three-level namespace (catalog.schema.model).

Registered models group a collection of model versions. Individual versions carry their own artifact storage location and are created, finalized, and governed independently.

Fields

name: &'a str

Name of registered model, relative to parent schema.

Field 1: name

catalog_name: &'a str

Name of parent catalog.

Field 2: catalog_name

schema_name: &'a str

Name of parent schema.

Field 3: schema_name

full_name: &'a str

The three-level (fully qualified) name of the registered model.

Format: catalog_name.schema_name.model_name

Field 4: full_name

storage_location: Option<&'a str>

The storage location under which model version data files are stored.

Field 5: storage_location

owner: Option<&'a str>

Username of current owner of the registered model.

Field 6: owner

comment: Option<&'a str>

User-provided free-form text description.

Field 7: comment

id: Option<&'a str>

Unique identifier for the registered model.

Field 8: id

created_at: Option<i64>

Time at which this registered model was created, in epoch milliseconds.

Field 1000: created_at

created_by: Option<&'a str>

Username of registered model creator.

Field 1001: created_by

updated_at: Option<i64>

Time at which this registered model was last updated, in epoch milliseconds.

Field 1002: updated_at

updated_by: Option<&'a str>

Username of user who last modified the registered model.

Field 1003: updated_by

metastore_id: Option<&'a str>

The unique identifier of the metastore.

Field 1004: metastore_id

browse_only: Option<bool>

Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.

Field 1005: browse_only

__buffa_unknown_fields: UnknownFieldsView<'a>