DataObjectView

Struct DataObjectView 

pub struct DataObjectView<'a> {
    pub name: &'a str,
    pub data_object_type: EnumValue<DataObjectType>,
    pub added_at: Option<i64>,
    pub added_by: Option<&'a str>,
    pub comment: Option<&'a str>,
    pub shared_as: Option<&'a str>,
    pub partitions: RepeatedView<'a, &'a str>,
    pub enable_cdf: Option<bool>,
    pub history_data_sharing_status: Option<EnumValue<HistoryStatus>>,
    pub start_version: Option<i64>,
    pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}

Fields

name: &'a str

A fully qualified name that uniquely identifies a data object.

For example, a table’s fully qualified name is in the format of <catalog>.<schema>.<table>,

Field 1: name

data_object_type: EnumValue<DataObjectType>

Type of the data object.

Field 2: data_object_type

added_at: Option<i64>

The time when this data object is added to the share, in epoch milliseconds.

Field 3: added_at

added_by: Option<&'a str>

Username of the sharer.

Field 4: added_by

comment: Option<&'a str>

A user-provided comment when adding the data object to the share.

Field 5: comment

shared_as: Option<&'a str>

A user-provided new name for the data object within the share.

If this new name is not provided, the object’s original name will be used as the shared_as name. The shared_as name must be unique within a share. For tables, the new name must follow the format of <schema>.<table>.

Field 6: shared_as

partitions: RepeatedView<'a, &'a str>

Array of partitions for the shared data.

Field 7: partitions

enable_cdf: Option<bool>

Whether to enable cdf or indicate if cdf is enabled on the shared object.

Field 8: enable_cdf

history_data_sharing_status: Option<EnumValue<HistoryStatus>>

Whether to enable or disable sharing of data history. If not specified, the default is DISABLED.

Field 9: history_data_sharing_status

start_version: Option<i64>

The start version associated with the object.

This allows data providers to control the lowest object version that is accessible by clients. If specified, clients can query snapshots or changes for versions >= start_version. If not specified, clients can only query starting from the version of the object at the time it was added to the share.

NOTE: The start_version should be <= the current version of the object.

Field 10: start_version

__buffa_unknown_fields: UnknownFieldsView<'a>