pub struct Agent {Show 17 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub full_name: String,
pub agent_id: String,
pub invocation_protocol: i32,
pub endpoint: String,
pub description: Option<String>,
pub capabilities: Vec<String>,
pub input_schema: Option<String>,
pub owner: Option<String>,
pub comment: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub metastore_id: Option<String>,
}Expand description
An agent registered in Unity Catalog.
Fields
name: StringName of the agent, relative to parent schema.
catalog_name: StringName of parent catalog.
schema_name: StringName of parent schema.
full_name: StringThe three-level (fully qualified) name of the agent.
agent_id: StringThe unique identifier of the agent.
invocation_protocol: i32The protocol a recipient uses to invoke the agent.
endpoint: StringThe agent’s invocation endpoint URL.
description: Option<String>An LLM-readable description of what the agent does and the inputs it expects.
capabilities: Vec<String>Capability identifiers advertised by the agent (e.g. sql_query,
document_search, code_execution).
input_schema: Option<String>A JSON Schema (encoded as a JSON string) describing the agent’s expected input payload. Kept as an opaque string so the schema can evolve without changing this message.
owner: Option<String>Username of current owner of the agent.
comment: Option<String>User-provided free-form text description.
created_at: Option<i64>Time at which this agent was created, in epoch milliseconds.
created_by: Option<String>Username of agent creator.
updated_at: Option<i64>Time at which this agent was last updated, in epoch milliseconds.
updated_by: Option<String>Username of user who last modified the agent.
metastore_id: Option<String>The unique identifier of the metastore.
Implementations
Sourceimpl Agent
impl Agent
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Agent
impl Agent
Sourcepub fn invocation_protocol(&self) -> InvocationProtocol
pub fn invocation_protocol(&self) -> InvocationProtocol
Returns the enum value of invocation_protocol, or the default if the field is set to an invalid enum value.
Sourcepub fn set_invocation_protocol(&mut self, value: InvocationProtocol)
pub fn set_invocation_protocol(&mut self, value: InvocationProtocol)
Sets invocation_protocol to the provided enum value.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn input_schema(&self) -> &str
pub fn input_schema(&self) -> &str
Returns the value of input_schema, or the default value if input_schema is unset.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.
Sourcepub fn metastore_id(&self) -> &str
pub fn metastore_id(&self) -> &str
Returns the value of metastore_id, or the default value if metastore_id is unset.