pub struct Catalog {Show 15 fields
pub name: String,
pub id: Option<String>,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub storage_root: Option<String>,
pub provider_name: Option<String>,
pub share_name: Option<String>,
pub catalog_type: Option<EnumValue<CatalogType>>,
pub storage_location: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub browse_only: Option<bool>,
/* private fields */
}Expand description
A catalog is a root-level namespace that contains schemas.
Fields
name: StringName of catalog.
Field 1: name
id: Option<String>Unique identifier for the catalog.
Field 2: id
owner: Option<String>Username of current owner of catalog.
Field 3: owner
comment: Option<String>User-provided free-form text description.
Field 4: comment
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Field 5: properties
storage_root: Option<String>Storage root URL for managed tables within catalog.
Field 6: storage_root
provider_name: Option<String>The name of delta sharing provider.
A Delta Sharing catalog is a catalog that is based on a Delta share on a remote sharing server.
Field 7: provider_name
The name of the share under the share provider.
Field 8: share_name
catalog_type: Option<EnumValue<CatalogType>>The type of the catalog.
Field 9: catalog_type
storage_location: Option<String>Storage location URL (full path) for managed storage of the catalog.
A unique path under storage_root, used as the managed-storage parent for
managed tables/volumes whose schema has no storage location of its own.
Absent when the catalog has no storage_root.
Example: s3://bucket/ucroot/__unitystorage/catalogs/{catalog_id}.
Field 10: storage_location
created_at: Option<i64>Time at which this catalog was created, in epoch milliseconds.
Field 1000: created_at
created_by: Option<String>Username of catalog creator.
Field 1001: created_by
updated_at: Option<i64>Time at which this catalog was last updated, in epoch milliseconds.
Field 1002: updated_at
updated_by: Option<String>Username of user who last modified catalog.
Field 1003: updated_by
browse_only: Option<bool>Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.
Field 1004: browse_only
Implementations
Sourceimpl Catalog
impl Catalog
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Catalog
impl Catalog
Sourcepub fn with_id(self, value: impl Into<String>) -> Self
pub fn with_id(self, value: impl Into<String>) -> Self
Sets Self::id to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_storage_root(self, value: impl Into<String>) -> Self
pub fn with_storage_root(self, value: impl Into<String>) -> Self
Sets Self::storage_root to Some(value), consuming and returning self.
Sourcepub fn with_provider_name(self, value: impl Into<String>) -> Self
pub fn with_provider_name(self, value: impl Into<String>) -> Self
Sets Self::provider_name to Some(value), consuming and returning self.
Sets Self::share_name to Some(value), consuming and returning self.
Sourcepub fn with_catalog_type(self, value: impl Into<EnumValue<CatalogType>>) -> Self
pub fn with_catalog_type(self, value: impl Into<EnumValue<CatalogType>>) -> Self
Sets Self::catalog_type to Some(value), consuming and returning self.
Sourcepub fn with_storage_location(self, value: impl Into<String>) -> Self
pub fn with_storage_location(self, value: impl Into<String>) -> Self
Sets Self::storage_location to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.
Sourcepub fn with_browse_only(self, value: bool) -> Self
pub fn with_browse_only(self, value: bool) -> Self
Sets Self::browse_only to Some(value), consuming and returning self.