pub struct Column {
pub name: String,
pub type_text: String,
pub type_json: String,
pub position: Option<i32>,
pub type_name: i32,
pub type_precision: Option<i32>,
pub type_scale: Option<i32>,
pub type_interval_type: Option<String>,
pub comment: Option<String>,
pub nullable: Option<bool>,
pub partition_index: Option<i32>,
pub column_id: Option<String>,
}Fields
name: StringName of the column
type_text: StringFull data type specification as SQL/catalogString text.
type_json: StringFull data type specification, JSON-serialized.
position: Option<i32>Ordinal position of column (starting at position 0).
type_name: i32Data type name.
type_precision: Option<i32>Digits of precision; required for DecimalTypes.
type_scale: Option<i32>Digits to right of decimal; Required for DecimalTypes.
type_interval_type: Option<String>Format of IntervalType.
comment: Option<String>User-provided free-form text description.
nullable: Option<bool>Whether field may be Null.
partition_index: Option<i32>Partition index for column.
column_id: Option<String>a unique id for the column
Implementations
Sourceimpl Column
impl Column
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Column
impl Column
Sourcepub fn position(&self) -> i32
pub fn position(&self) -> i32
Returns the value of position, or the default value if position is unset.
Sourcepub fn type_name(&self) -> ColumnTypeName
pub fn type_name(&self) -> ColumnTypeName
Returns the enum value of type_name, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type_name(&mut self, value: ColumnTypeName)
pub fn set_type_name(&mut self, value: ColumnTypeName)
Sets type_name to the provided enum value.
Sourcepub fn type_precision(&self) -> i32
pub fn type_precision(&self) -> i32
Returns the value of type_precision, or the default value if type_precision is unset.
Sourcepub fn type_scale(&self) -> i32
pub fn type_scale(&self) -> i32
Returns the value of type_scale, or the default value if type_scale is unset.
Sourcepub fn type_interval_type(&self) -> &str
pub fn type_interval_type(&self) -> &str
Returns the value of type_interval_type, or the default value if type_interval_type is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn nullable(&self) -> bool
pub fn nullable(&self) -> bool
Returns the value of nullable, or the default value if nullable is unset.
Sourcepub fn partition_index(&self) -> i32
pub fn partition_index(&self) -> i32
Returns the value of partition_index, or the default value if partition_index is unset.