pub struct ExternalLocation {Show 13 fields
pub name: String,
pub url: String,
pub credential_name: String,
pub read_only: bool,
pub comment: Option<String>,
pub owner: Option<String>,
pub credential_id: String,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub browse_only: Option<bool>,
pub external_location_id: Option<String>,
/* private fields */
}Fields
name: StringName of the external location.
Field 1: name
url: StringPath URL of the external location.
Field 2: url
credential_name: StringName of the storage credential used with this location.
Field 3: credential_name
read_only: boolIndicates whether the external location is read-only.
Field 4: read_only
comment: Option<String>User-provided free-form text description.
Field 5: comment
owner: Option<String>The owner of the external location.
Field 6: owner
credential_id: Stringmetastore id string metastore_id = 7;
Unique ID of the location’s storage credential.
Field 8: credential_id
created_at: Option<i64>Time at which this catalog was created, in epoch milliseconds.
Field 9: created_at
created_by: Option<String>Username of catalog creator.
Field 10: created_by
updated_at: Option<i64>Time at which this catalog was last updated, in epoch milliseconds.
Field 11: updated_at
updated_by: Option<String>Username of user who last modified catalog.
Field 12: updated_by
browse_only: Option<bool>Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.
Field 13: browse_only
external_location_id: Option<String>Field 100: external_location_id
Implementations
Sourceimpl ExternalLocation
impl ExternalLocation
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl ExternalLocation
impl ExternalLocation
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.
Sourcepub fn with_browse_only(self, value: bool) -> Self
pub fn with_browse_only(self, value: bool) -> Self
Sets Self::browse_only to Some(value), consuming and returning self.
Sourcepub fn with_external_location_id(self, value: impl Into<String>) -> Self
pub fn with_external_location_id(self, value: impl Into<String>) -> Self
Sets Self::external_location_id to Some(value), consuming and returning self.