pub struct Function {Show 26 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub full_name: String,
pub data_type: String,
pub full_data_type: String,
pub input_params: Option<FunctionParameterInfos>,
pub return_params: Option<String>,
pub routine_body_language: Option<String>,
pub routine_definition: Option<String>,
pub routine_dependencies: Option<String>,
pub parameter_style: i32,
pub is_deterministic: bool,
pub sql_data_access: i32,
pub is_null_call: bool,
pub security_type: i32,
pub specific_name: Option<String>,
pub routine_body: i32,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub owner: Option<String>,
pub function_id: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
}Expand description
A User-Defined Function (UDF) registered under a catalog + schema hierarchy.
Fields
name: StringName of function, relative to parent schema.
catalog_name: StringName of parent catalog.
schema_name: StringName of parent schema.
full_name: StringThe three-level (fully qualified) name of the function.
Format: catalog_name.schema_name.function_name
data_type: StringFull data type specification of the return type of the function.
full_data_type: StringFull data type specification as SQL/catalogString text.
input_params: Option<FunctionParameterInfos>The array of function parameter infos.
return_params: Option<String>The return type of the function in JSON format.
routine_body_language: Option<String>The language of the function routine body.
routine_definition: Option<String>Function body.
routine_dependencies: Option<String>Function dependencies (in JSON form).
parameter_style: i32The parameter-passing style.
is_deterministic: boolIndicates whether the function is deterministic.
sql_data_access: i32SQL data access information.
is_null_call: boolIndicates whether the function is null-calling.
security_type: i32The security type of the function.
specific_name: Option<String>The type of the function (SCALAR or TABLE).
routine_body: i32The routine body.
comment: Option<String>User-provided free-form text description.
properties: HashMap<String, String>A map of key-value properties attached to the securable.
owner: Option<String>Username of current owner of the function.
function_id: Option<String>Unique identifier for the function.
created_at: Option<i64>Time at which this function was created, in epoch milliseconds.
created_by: Option<String>Username of function creator.
updated_at: Option<i64>Time at which this function was last updated, in epoch milliseconds.
updated_by: Option<String>Username of user who last modified the function.
Implementations
Sourceimpl Function
impl Function
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Function
impl Function
Sourcepub fn return_params(&self) -> &str
pub fn return_params(&self) -> &str
Returns the value of return_params, or the default value if return_params is unset.
Sourcepub fn routine_body_language(&self) -> &str
pub fn routine_body_language(&self) -> &str
Returns the value of routine_body_language, or the default value if routine_body_language is unset.
Sourcepub fn routine_definition(&self) -> &str
pub fn routine_definition(&self) -> &str
Returns the value of routine_definition, or the default value if routine_definition is unset.
Sourcepub fn routine_dependencies(&self) -> &str
pub fn routine_dependencies(&self) -> &str
Returns the value of routine_dependencies, or the default value if routine_dependencies is unset.
Sourcepub fn parameter_style(&self) -> ParameterStyle
pub fn parameter_style(&self) -> ParameterStyle
Returns the enum value of parameter_style, or the default if the field is set to an invalid enum value.
Sourcepub fn set_parameter_style(&mut self, value: ParameterStyle)
pub fn set_parameter_style(&mut self, value: ParameterStyle)
Sets parameter_style to the provided enum value.
Sourcepub fn sql_data_access(&self) -> SqlDataAccess
pub fn sql_data_access(&self) -> SqlDataAccess
Returns the enum value of sql_data_access, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sql_data_access(&mut self, value: SqlDataAccess)
pub fn set_sql_data_access(&mut self, value: SqlDataAccess)
Sets sql_data_access to the provided enum value.
Sourcepub fn security_type(&self) -> SecurityType
pub fn security_type(&self) -> SecurityType
Returns the enum value of security_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_security_type(&mut self, value: SecurityType)
pub fn set_security_type(&mut self, value: SecurityType)
Sets security_type to the provided enum value.
Sourcepub fn specific_name(&self) -> &str
pub fn specific_name(&self) -> &str
Returns the value of specific_name, or the default value if specific_name is unset.
Sourcepub fn routine_body(&self) -> RoutineBody
pub fn routine_body(&self) -> RoutineBody
Returns the enum value of routine_body, or the default if the field is set to an invalid enum value.
Sourcepub fn set_routine_body(&mut self, value: RoutineBody)
pub fn set_routine_body(&mut self, value: RoutineBody)
Sets routine_body to the provided enum value.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn function_id(&self) -> &str
pub fn function_id(&self) -> &str
Returns the value of function_id, or the default value if function_id is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.