pub struct Provider {
pub id: Option<String>,
pub name: String,
pub authentication_type: EnumValue<ProviderAuthenticationType>,
pub owner: Option<String>,
pub comment: Option<String>,
pub recipient_profile_str: Option<String>,
pub properties: HashMap<String, String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
/* private fields */
}Expand description
A provider represents an organization sharing data with this metastore.
A provider is the inbound counterpart of a recipient: it is registered from a share activation/credential file and is used to access shares offered by an upstream Delta Sharing server.
Fields
id: Option<String>Unique ID of the provider.
Field 100: id
name: StringThe name of the provider.
Field 1: name
authentication_type: EnumValue<ProviderAuthenticationType>The delta sharing authentication type.
Field 2: authentication_type
owner: Option<String>Username of the provider owner.
Field 3: owner
comment: Option<String>Description about the provider.
Field 4: comment
recipient_profile_str: Option<String>The recipient profile (credential file contents) used to connect to the sharing server, present only for TOKEN authentication.
Field 5: recipient_profile_str
properties: HashMap<String, String>A map of key-value properties attached to the provider.
Field 6: properties
created_at: Option<i64>Time at which this provider was created, in epoch milliseconds.
Field 7: created_at
created_by: Option<String>Username of the creator of the provider.
Field 8: created_by
updated_at: Option<i64>Time at which this provider was updated, in epoch milliseconds.
Field 9: updated_at
updated_by: Option<String>Username of the provider updater.
Field 10: updated_by
Implementations
Sourceimpl Provider
impl Provider
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Provider
impl Provider
Sourcepub fn with_id(self, value: impl Into<String>) -> Self
pub fn with_id(self, value: impl Into<String>) -> Self
Sets Self::id to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_recipient_profile_str(self, value: impl Into<String>) -> Self
pub fn with_recipient_profile_str(self, value: impl Into<String>) -> Self
Sets Self::recipient_profile_str to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.