pub struct Recipient {
pub id: Option<String>,
pub name: String,
pub authentication_type: EnumValue<AuthenticationType>,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub tokens: Vec<RecipientToken>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
/* private fields */
}Fields
id: Option<String>Unique ID of the recipient.
Field 100: id
name: StringThe name of the recipient.
Field 1: name
authentication_type: EnumValue<AuthenticationType>The delta sharing authentication type.
Field 2: authentication_type
owner: Option<String>Username of the recipient owner.
Field 3: owner
comment: Option<String>Description about the recipient.
Field 4: comment
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Field 6: properties
created_at: Option<i64>Time at which this share was created, in epoch milliseconds.
Field 7: created_at
created_by: Option<String>Username of the creator of the share.
Field 8: created_by
tokens: Vec<RecipientToken>This field is only present when the authentication_type is TOKEN.
Field 9: tokens
updated_at: Option<i64>Time at which this share was updated, in epoch milliseconds.
Field 10: updated_at
updated_by: Option<String>Username of share updater.
Field 11: updated_by
Implementations
Sourceimpl Recipient
impl Recipient
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Recipient
impl Recipient
Sourcepub fn with_id(self, value: impl Into<String>) -> Self
pub fn with_id(self, value: impl Into<String>) -> Self
Sets Self::id to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.