pub struct Schema {Show 13 fields
pub name: String,
pub catalog_name: String,
pub full_name: String,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub owner: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub schema_id: Option<String>,
pub storage_root: Option<String>,
pub storage_location: Option<String>,
/* private fields */
}Expand description
A schema is a namespace within a catalog that contains tables.
Fields
name: StringName of schema, relative to parent catalog.
Field 1: name
catalog_name: StringName of parent catalog.
Field 2: catalog_name
full_name: StringFull name of schema, in form of catalog_name.schema_name.
Field 3: full_name
comment: Option<String>User-provided free-form text description.
Field 4: comment
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Field 5: properties
owner: Option<String>Username of current owner of schema.
Field 6: owner
created_at: Option<i64>Time at which this schema was created, in epoch milliseconds.
Field 7: created_at
created_by: Option<String>Username of schema creator.
Field 8: created_by
updated_at: Option<i64>Time at which this schema was last updated, in epoch milliseconds.
Field 9: updated_at
updated_by: Option<String>Username of user who last modified schema.
Field 10: updated_by
schema_id: Option<String>Unique identifier for the schema.
Field 11: schema_id
storage_root: Option<String>Storage root URL for managed storage location of the schema.
Can be set when creating a schema. When set, managed tables/volumes created
in this schema are rooted here; otherwise the parent catalog’s storage
location is used. Example: s3://bucket/ucroot.
Field 12: storage_root
storage_location: Option<String>Storage location URL (full path) for managed storage of the schema.
A unique path under storage_root. Absent when the schema has no
storage_root, in which case managed securables fall back to the parent
catalog’s storage location.
Example: s3://bucket/ucroot/__unitystorage/schemas/{schema_id}.
Field 13: storage_location
Implementations
Sourceimpl Schema
impl Schema
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Schema
impl Schema
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.
Sourcepub fn with_schema_id(self, value: impl Into<String>) -> Self
pub fn with_schema_id(self, value: impl Into<String>) -> Self
Sets Self::schema_id to Some(value), consuming and returning self.
Sourcepub fn with_storage_root(self, value: impl Into<String>) -> Self
pub fn with_storage_root(self, value: impl Into<String>) -> Self
Sets Self::storage_root to Some(value), consuming and returning self.
Sourcepub fn with_storage_location(self, value: impl Into<String>) -> Self
pub fn with_storage_location(self, value: impl Into<String>) -> Self
Sets Self::storage_location to Some(value), consuming and returning self.