pub struct Table {Show 20 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub table_type: EnumValue<TableType>,
pub data_source_format: EnumValue<DataSourceFormat>,
pub columns: Vec<Column>,
pub storage_location: Option<String>,
pub view_definition: Option<String>,
pub view_dependencies: MessageField<DependencyList>,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub storage_credential_name: Option<String>,
pub full_name: String,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub deleted_at: Option<i64>,
pub table_id: Option<String>,
/* private fields */
}Fields
name: StringName of table, relative to parent schema.
Field 1: name
catalog_name: StringName of parent catalog.
Field 2: catalog_name
schema_name: StringName of parent schema.
Field 3: schema_name
table_type: EnumValue<TableType>Field 4: table_type
data_source_format: EnumValue<DataSourceFormat>Data source format of the table.
Field 5: data_source_format
columns: Vec<Column>The array of Column definitions of the table’s columns.
Field 6: columns
storage_location: Option<String>Storage root URL for table (for MANAGED, EXTERNAL tables)
Field 7: storage_location
view_definition: Option<String>Definition text for view-like table types (VIEW, MATERIALIZED_VIEW, STREAMING_TABLE, METRIC_VIEW). The format depends on the table type: SQL for views, YAML for metric views.
Field 8: view_definition
view_dependencies: MessageField<DependencyList>Tables and functions the view-like table reads. For metric views this is derived from the view_definition by the server (the definition is the single source of truth).
Field 9: view_dependencies
owner: Option<String>optional string sql_path = 10;
Username of current owner of table.
Field 11: owner
comment: Option<String>User-provided free-form text description.
Field 12: comment
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Field 13: properties
storage_credential_name: Option<String>Name of the storage credential, when a storage credential is configured for use with this table.
Field 14: storage_credential_name
full_name: StringList of table constraints. Note: this field is not set in the output of the listTables API. repeated TableConstraint constraints = 15;
optional string row_filter = 16;
Full name of table, in form of catalog_name.schema_name.table_name.
Field 17: full_name
created_at: Option<i64>Time at which this table was created, in epoch milliseconds.
Field 18: created_at
created_by: Option<String>Username of table creator.
Field 19: created_by
updated_at: Option<i64>Time at which this table was last updated, in epoch milliseconds.
Field 20: updated_at
updated_by: Option<String>Username of user who last modified table.
Field 21: updated_by
deleted_at: Option<i64>Time at which this table was deleted, in epoch milliseconds. Field is omitted if table is not deleted.
Field 22: deleted_at
table_id: Option<String>Unique identifier for the table.
Field 23: table_id
Implementations
Sourceimpl Table
impl Table
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Table
impl Table
Sourcepub fn with_storage_location(self, value: impl Into<String>) -> Self
pub fn with_storage_location(self, value: impl Into<String>) -> Self
Sets Self::storage_location to Some(value), consuming and returning self.
Sourcepub fn with_view_definition(self, value: impl Into<String>) -> Self
pub fn with_view_definition(self, value: impl Into<String>) -> Self
Sets Self::view_definition to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_storage_credential_name(self, value: impl Into<String>) -> Self
pub fn with_storage_credential_name(self, value: impl Into<String>) -> Self
Sets Self::storage_credential_name to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.
Sourcepub fn with_deleted_at(self, value: i64) -> Self
pub fn with_deleted_at(self, value: i64) -> Self
Sets Self::deleted_at to Some(value), consuming and returning self.
Sourcepub fn with_table_id(self, value: impl Into<String>) -> Self
pub fn with_table_id(self, value: impl Into<String>) -> Self
Sets Self::table_id to Some(value), consuming and returning self.