pub struct Volume {Show 15 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub full_name: String,
pub storage_location: String,
pub volume_id: String,
pub volume_type: EnumValue<VolumeType>,
pub owner: Option<String>,
pub comment: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub browse_only: Option<bool>,
pub metastore_id: Option<String>,
/* private fields */
}Fields
name: StringName of volume, relative to parent schema.
Field 1: name
catalog_name: StringName of parent catalog.
Field 2: catalog_name
schema_name: StringName of parent schema.
Field 3: schema_name
full_name: StringThe three-level (fully qualified) name of the volume
Field 4: full_name
storage_location: StringThe storage location on the cloud
Field 5: storage_location
volume_id: StringThe unique identifier of the volume
Field 6: volume_id
volume_type: EnumValue<VolumeType>The type of the volume.
An external volume is located in the specified external location. A managed volume is located in the default location which is specified by the parent schema, or the parent catalog, or the Metastore.
Field 7: volume_type
owner: Option<String>Username of current owner of table.
Field 8: owner
comment: Option<String>User-provided free-form text description.
Field 9: comment
created_at: Option<i64>Time at which this catalog was created, in epoch milliseconds.
Field 1000: created_at
created_by: Option<String>Username of catalog creator.
Field 1001: created_by
updated_at: Option<i64>Time at which this catalog was last updated, in epoch milliseconds.
Field 1002: updated_at
updated_by: Option<String>Username of user who last modified catalog.
Field 1003: updated_by
browse_only: Option<bool>Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.
Field 1004: browse_only
metastore_id: Option<String>The unique identifier of the metastore
Field 1005: metastore_id
Implementations
Sourceimpl Volume
impl Volume
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Volume
impl Volume
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.
Sourcepub fn with_browse_only(self, value: bool) -> Self
pub fn with_browse_only(self, value: bool) -> Self
Sets Self::browse_only to Some(value), consuming and returning self.
Sourcepub fn with_metastore_id(self, value: impl Into<String>) -> Self
pub fn with_metastore_id(self, value: impl Into<String>) -> Self
Sets Self::metastore_id to Some(value), consuming and returning self.