pub struct GetTableRequest {
pub full_name: String,
pub include_delta_metadata: Option<bool>,
pub include_browse: Option<bool>,
pub include_manifest_capabilities: Option<bool>,
}Expand description
Get a table
Fields
full_name: StringFull name of the table.
include_delta_metadata: Option<bool>Whether delta metadata should be included in the response.
include_browse: Option<bool>Whether to include tables in the response for which the principal can only access selective metadata for
include_manifest_capabilities: Option<bool>Whether to include a manifest containing capabilities the table has.
Implementations
Sourceimpl GetTableRequest
impl GetTableRequest
Sourcepub fn include_delta_metadata(&self) -> bool
pub fn include_delta_metadata(&self) -> bool
Returns the value of include_delta_metadata, or the default value if include_delta_metadata is unset.
Sourcepub fn include_browse(&self) -> bool
pub fn include_browse(&self) -> bool
Returns the value of include_browse, or the default value if include_browse is unset.
Sourcepub fn include_manifest_capabilities(&self) -> bool
pub fn include_manifest_capabilities(&self) -> bool
Returns the value of include_manifest_capabilities, or the default value if include_manifest_capabilities is unset.