TableView

Struct TableView 

pub struct TableView<'a> {
Show 21 fields pub name: &'a str, pub catalog_name: &'a str, pub schema_name: &'a str, pub table_type: EnumValue<TableType>, pub data_source_format: EnumValue<DataSourceFormat>, pub columns: RepeatedView<'a, ColumnView<'a>>, pub storage_location: Option<&'a str>, pub view_definition: Option<&'a str>, pub view_dependencies: MessageFieldView<DependencyListView<'a>>, pub owner: Option<&'a str>, pub comment: Option<&'a str>, pub properties: MapView<'a, &'a str, &'a str>, pub storage_credential_name: Option<&'a str>, pub full_name: &'a str, pub created_at: Option<i64>, pub created_by: Option<&'a str>, pub updated_at: Option<i64>, pub updated_by: Option<&'a str>, pub deleted_at: Option<i64>, pub table_id: Option<&'a str>, pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}

Fields

name: &'a str

Name of table, relative to parent schema.

Field 1: name

catalog_name: &'a str

Name of parent catalog.

Field 2: catalog_name

schema_name: &'a str

Name of parent schema.

Field 3: schema_name

table_type: EnumValue<TableType>

Field 4: table_type

data_source_format: EnumValue<DataSourceFormat>

Data source format of the table.

Field 5: data_source_format

columns: RepeatedView<'a, ColumnView<'a>>

The array of Column definitions of the table’s columns.

Field 6: columns

storage_location: Option<&'a str>

Storage root URL for table (for MANAGED, EXTERNAL tables)

Field 7: storage_location

view_definition: Option<&'a str>

Definition text for view-like table types (VIEW, MATERIALIZED_VIEW, STREAMING_TABLE, METRIC_VIEW). The format depends on the table type: SQL for views, YAML for metric views.

Field 8: view_definition

view_dependencies: MessageFieldView<DependencyListView<'a>>

Tables and functions the view-like table reads. For metric views this is derived from the view_definition by the server (the definition is the single source of truth).

Field 9: view_dependencies

owner: Option<&'a str>

optional string sql_path = 10;

Username of current owner of table.

Field 11: owner

comment: Option<&'a str>

User-provided free-form text description.

Field 12: comment

properties: MapView<'a, &'a str, &'a str>

A map of key-value properties attached to the securable.

Field 13: properties (map)

storage_credential_name: Option<&'a str>

Name of the storage credential, when a storage credential is configured for use with this table.

Field 14: storage_credential_name

full_name: &'a str

List of table constraints. Note: this field is not set in the output of the listTables API. repeated TableConstraint constraints = 15;

optional string row_filter = 16;

Full name of table, in form of catalog_name.schema_name.table_name.

Field 17: full_name

created_at: Option<i64>

Time at which this table was created, in epoch milliseconds.

Field 18: created_at

created_by: Option<&'a str>

Username of table creator.

Field 19: created_by

updated_at: Option<i64>

Time at which this table was last updated, in epoch milliseconds.

Field 20: updated_at

updated_by: Option<&'a str>

Username of user who last modified table.

Field 21: updated_by

deleted_at: Option<i64>

Time at which this table was deleted, in epoch milliseconds. Field is omitted if table is not deleted.

Field 22: deleted_at

table_id: Option<&'a str>

Unique identifier for the table.

Field 23: table_id

__buffa_unknown_fields: UnknownFieldsView<'a>