GenerateTemporaryPathCredentialsRequest

Struct GenerateTemporaryPathCredentialsRequest 

pub struct GenerateTemporaryPathCredentialsRequest {
    pub url: String,
    pub operation: EnumValue<Operation>,
    pub dry_run: Option<bool>,
    /* private fields */
}
Generate a new set of credentials for a path.

Fields

url: String

URL for path-based access.

Field 1: url

operation: EnumValue<Operation>

The operation being performed on the path.

Field 2: operation

dry_run: Option<bool>

When set to true, the service will not validate that the generated credentials can perform write operations, therefore no new paths will be created and the response will not contain valid credentials. Defaults to false.

Field 3: dry_run

Implementations

Source

impl GenerateTemporaryPathCredentialsRequest

pub const TYPE_URL: &'static str = "type.googleapis.com/unitycatalog.temporary_credentials.v1.GenerateTemporaryPathCredentialsRequest"

Protobuf type URL for this message, for use with Any::pack and Any::unpack_if.

Format: type.googleapis.com/<fully.qualified.TypeName>

Source

impl GenerateTemporaryPathCredentialsRequest

pub fn with_dry_run(self, value: bool) -> Self

Sets Self::dry_run to Some(value), consuming and returning self.