GenerateTemporaryPathCredentialsRequestView

Struct GenerateTemporaryPathCredentialsRequestView 

pub struct GenerateTemporaryPathCredentialsRequestView<'a> {
    pub url: &'a str,
    pub operation: EnumValue<Operation>,
    pub dry_run: Option<bool>,
    pub __buffa_unknown_fields: UnknownFieldsView<'a>,
}
Generate a new set of credentials for a path.

Fields

url: &'a str

URL for path-based access.

Field 1: url

operation: EnumValue<Operation>

The operation being performed on the path.

Field 2: operation

dry_run: Option<bool>

When set to true, the service will not validate that the generated credentials can perform write operations, therefore no new paths will be created and the response will not contain valid credentials. Defaults to false.

Field 3: dry_run

__buffa_unknown_fields: UnknownFieldsView<'a>