pub struct R2TemporaryCredentials {
pub access_key_id: String,
pub secret_access_key: String,
pub session_token: String,
/* private fields */
}Fields
access_key_id: StringThe access key ID that identifies the temporary credentials.
Field 1: access_key_id
secret_access_key: StringThe secret access key associated with the access key.
Field 2: secret_access_key
session_token: StringThe generated JWT that users must pass to use the temporary credentials.
Field 3: session_token
Implementations