Modules
- agent_
skills - agents
- catalogs
- credentials
- external_
locations - functions
- labels
- model_
versions - policies
- providers
- recipients
- registered_
models - schemas
- shares
- staging_
tables - tables
- tags
- temporary_
credentials - volumes
Macros
- resource_
name - Creates a nested column name whose field names are all simple resource names (containing only alphanumeric characters and underscores), delimited by dots. This macro is provided as a convenience for the common case where the caller knows the column name contains only simple field names and that splitting by periods is safe:
Structs
- Agent
- An agent registered in Unity Catalog.
- Agent
Skill - An agent skill registered in Unity Catalog.
- Catalog
- A catalog is a root-level namespace that contains schemas.
- Column
- Credential
- A credential used to access external data sources or services.
- Error
Response - External
Location - Function
- A User-Defined Function (UDF) registered under a catalog + schema hierarchy.
- Model
Version - A model version under a registered model.
- Policy
Info - A row-filter or column-mask policy bound to principals and scoped to a securable.
- Provider
- A provider represents an organization sharing data with this metastore.
- Recipient
- Registered
Model - A registered model within the three-level namespace (catalog.schema.model).
- Resource
Name - A (possibly nested) resource name: a path of field-name segments.
- Schema
- A schema is a namespace within a catalog that contains tables.
- Share
- Staging
Table - A staging table is a transient reservation created while provisioning a Unity Catalog managed table.
- Table
- TagPolicy
- A governed tag definition (tag policy).
- Volume
Enums
- Association
Label - Object
Label - Discriminant label for each resource type.
- Resource
- All resource types managed by the service.
- Resource
Ident - Resource that a policy can authorize.
- Resource
Ref - A reference to a resource, by id, by name, or unspecified.
Statics
- EMPTY_
RESOURCE_ NAME - A shared, empty
ResourceName(a zero-segment path).
Traits
Type Aliases
- Object
- Project-specific alias for
resource_store::Objectwith our generatedObjectLabel. - Property
Map