#[repr(i32)]pub enum InvocationProtocol {
Unspecified = 0,
Mcp = 1,
A2a = 2,
Openai = 3,
Anthropic = 4,
Rest = 5,
}Expand description
The protocol a recipient uses to invoke an agent.
Variants
Unspecified = 0
Mcp = 1
Model Context Protocol server.
A2a = 2
Agent-to-Agent protocol (Google A2A spec).
Openai = 3
OpenAI-compatible chat completions endpoint.
Anthropic = 4
Anthropic-compatible messages endpoint.
Rest = 5
Minimal REST baseline (POST {endpoint}/invoke).
Implementations
Sourceimpl InvocationProtocol
impl InvocationProtocol
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of InvocationProtocol.
Sourcepub fn from_i32(value: i32) -> Option<InvocationProtocol>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<InvocationProtocol>
Use the TryFrom<i32> implementation instead
Converts an i32 to a InvocationProtocol, or None if value is not a valid variant.
Sourceimpl InvocationProtocol
impl InvocationProtocol
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.