pub struct CreateAgentRequest {
pub catalog_name: String,
pub schema_name: String,
pub name: String,
pub invocation_protocol: i32,
pub endpoint: String,
pub description: Option<String>,
pub capabilities: Vec<String>,
pub input_schema: Option<String>,
pub comment: Option<String>,
}Expand description
Create a new agent.
Fields
catalog_name: StringThe identifier of the catalog.
schema_name: StringThe identifier of the schema.
name: StringThe identifier of the agent.
invocation_protocol: i32The protocol a recipient uses to invoke the agent.
endpoint: StringThe agent’s invocation endpoint URL.
description: Option<String>An LLM-readable description of what the agent does and the inputs it expects.
capabilities: Vec<String>Capability identifiers advertised by the agent.
input_schema: Option<String>A JSON Schema (encoded as a JSON string) describing the expected input.
comment: Option<String>User-provided free-form text description.
Implementations
Sourceimpl CreateAgentRequest
impl CreateAgentRequest
Sourcepub fn invocation_protocol(&self) -> InvocationProtocol
pub fn invocation_protocol(&self) -> InvocationProtocol
Returns the enum value of invocation_protocol, or the default if the field is set to an invalid enum value.
Sourcepub fn set_invocation_protocol(&mut self, value: InvocationProtocol)
pub fn set_invocation_protocol(&mut self, value: InvocationProtocol)
Sets invocation_protocol to the provided enum value.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn input_schema(&self) -> &str
pub fn input_schema(&self) -> &str
Returns the value of input_schema, or the default value if input_schema is unset.