pub struct ListCredentialsRequest {
pub purpose: Option<i32>,
pub max_results: Option<i32>,
pub page_token: Option<String>,
}Fields
purpose: Option<i32>Return only credentials for the specified purpose.
max_results: Option<i32>The maximum number of results per page that should be returned.
page_token: Option<String>Opaque pagination token to go to next page based on previous query.
Implementations
Sourceimpl ListCredentialsRequest
impl ListCredentialsRequest
Sourcepub fn purpose(&self) -> Purpose
pub fn purpose(&self) -> Purpose
Returns the enum value of purpose, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_purpose(&mut self, value: Purpose)
pub fn set_purpose(&mut self, value: Purpose)
Sets purpose to the provided enum value.
Sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
Returns the value of max_results, or the default value if max_results is unset.
Sourcepub fn page_token(&self) -> &str
pub fn page_token(&self) -> &str
Returns the value of page_token, or the default value if page_token is unset.