pub struct CreateFunction {Show 16 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub data_type: String,
pub full_data_type: String,
pub input_params: MessageField<FunctionParameterInfos>,
pub parameter_style: EnumValue<ParameterStyle>,
pub is_deterministic: bool,
pub sql_data_access: EnumValue<SqlDataAccess>,
pub is_null_call: bool,
pub security_type: EnumValue<SecurityType>,
pub routine_body: EnumValue<RoutineBody>,
pub routine_definition: Option<String>,
pub routine_body_language: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
/* private fields */
}Expand description
The payload for creating a new function.
Wrapped in the function_info envelope of a CreateFunctionRequest, matching
the Unity Catalog POST /functions wire contract.
Fields
name: StringName of function, relative to parent schema.
Field 1: name
catalog_name: StringName of parent catalog.
Field 2: catalog_name
schema_name: StringName of parent schema.
Field 3: schema_name
data_type: StringFull data type specification of the return type of the function.
Field 4: data_type
full_data_type: StringFull data type specification as SQL/catalogString text.
Field 5: full_data_type
input_params: MessageField<FunctionParameterInfos>The array of function parameter infos.
Field 6: input_params
parameter_style: EnumValue<ParameterStyle>The parameter-passing style.
Field 7: parameter_style
is_deterministic: boolIndicates whether the function is deterministic.
Field 8: is_deterministic
sql_data_access: EnumValue<SqlDataAccess>SQL data access information.
Field 9: sql_data_access
is_null_call: boolIndicates whether the function is null-calling.
Field 10: is_null_call
security_type: EnumValue<SecurityType>The security type of the function.
Field 11: security_type
routine_body: EnumValue<RoutineBody>The routine body.
Field 12: routine_body
routine_definition: Option<String>Function body.
Field 13: routine_definition
routine_body_language: Option<String>The language of the function routine body.
Field 14: routine_body_language
comment: Option<String>User-provided free-form text description.
Field 15: comment
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Field 16: properties
Implementations
Sourceimpl CreateFunction
impl CreateFunction
Sourcepub fn with_routine_definition(self, value: impl Into<String>) -> Self
pub fn with_routine_definition(self, value: impl Into<String>) -> Self
Sets Self::routine_definition to Some(value), consuming and returning self.
Sourcepub fn with_routine_body_language(self, value: impl Into<String>) -> Self
pub fn with_routine_body_language(self, value: impl Into<String>) -> Self
Sets Self::routine_body_language to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourceimpl CreateFunction
impl CreateFunction
Sourcepub fn new(
name: impl Into<String>,
catalog_name: impl Into<String>,
schema_name: impl Into<String>,
data_type: impl Into<String>,
full_data_type: impl Into<String>,
parameter_style: ParameterStyle,
is_deterministic: bool,
sql_data_access: SqlDataAccess,
is_null_call: bool,
security_type: SecurityType,
routine_body: RoutineBody,
) -> Self
pub fn new( name: impl Into<String>, catalog_name: impl Into<String>, schema_name: impl Into<String>, data_type: impl Into<String>, full_data_type: impl Into<String>, parameter_style: ParameterStyle, is_deterministic: bool, sql_data_access: SqlDataAccess, is_null_call: bool, security_type: SecurityType, routine_body: RoutineBody, ) -> Self
Create a CreateFunction payload from the required function attributes.
Optional fields (input params, routine definition, comment, properties, …) are
left unset and can be added with the with_* methods.
Sourcepub fn with_input_params(
self,
input_params: impl Into<Option<FunctionParameterInfos>>,
) -> Self
pub fn with_input_params( self, input_params: impl Into<Option<FunctionParameterInfos>>, ) -> Self
Set the array of function parameter infos.
Sourcepub fn with_properties<I, K, V>(self, properties: I) -> Self
pub fn with_properties<I, K, V>(self, properties: I) -> Self
Set the key-value properties attached to the securable.