pub struct CreateFunctionRequest {Show 16 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub data_type: String,
pub full_data_type: String,
pub input_params: Option<FunctionParameterInfos>,
pub parameter_style: i32,
pub is_deterministic: bool,
pub sql_data_access: i32,
pub is_null_call: bool,
pub security_type: i32,
pub routine_body: i32,
pub routine_definition: Option<String>,
pub routine_body_language: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
}Expand description
Create a new function
Fields
name: StringName of function, relative to parent schema.
catalog_name: StringName of parent catalog.
schema_name: StringName of parent schema.
data_type: StringFull data type specification of the return type of the function.
full_data_type: StringFull data type specification as SQL/catalogString text.
input_params: Option<FunctionParameterInfos>The array of function parameter infos.
parameter_style: i32The parameter-passing style.
is_deterministic: boolIndicates whether the function is deterministic.
sql_data_access: i32SQL data access information.
is_null_call: boolIndicates whether the function is null-calling.
security_type: i32The security type of the function.
routine_body: i32The routine body.
routine_definition: Option<String>Function body.
routine_body_language: Option<String>The language of the function routine body.
comment: Option<String>User-provided free-form text description.
properties: HashMap<String, String>A map of key-value properties attached to the securable.
Implementations
Sourceimpl CreateFunctionRequest
impl CreateFunctionRequest
Sourcepub fn parameter_style(&self) -> ParameterStyle
pub fn parameter_style(&self) -> ParameterStyle
Returns the enum value of parameter_style, or the default if the field is set to an invalid enum value.
Sourcepub fn set_parameter_style(&mut self, value: ParameterStyle)
pub fn set_parameter_style(&mut self, value: ParameterStyle)
Sets parameter_style to the provided enum value.
Sourcepub fn sql_data_access(&self) -> SqlDataAccess
pub fn sql_data_access(&self) -> SqlDataAccess
Returns the enum value of sql_data_access, or the default if the field is set to an invalid enum value.
Sourcepub fn set_sql_data_access(&mut self, value: SqlDataAccess)
pub fn set_sql_data_access(&mut self, value: SqlDataAccess)
Sets sql_data_access to the provided enum value.
Sourcepub fn security_type(&self) -> SecurityType
pub fn security_type(&self) -> SecurityType
Returns the enum value of security_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_security_type(&mut self, value: SecurityType)
pub fn set_security_type(&mut self, value: SecurityType)
Sets security_type to the provided enum value.
Sourcepub fn routine_body(&self) -> RoutineBody
pub fn routine_body(&self) -> RoutineBody
Returns the enum value of routine_body, or the default if the field is set to an invalid enum value.
Sourcepub fn set_routine_body(&mut self, value: RoutineBody)
pub fn set_routine_body(&mut self, value: RoutineBody)
Sets routine_body to the provided enum value.
Sourcepub fn routine_definition(&self) -> &str
pub fn routine_definition(&self) -> &str
Returns the value of routine_definition, or the default value if routine_definition is unset.
Sourcepub fn routine_body_language(&self) -> &str
pub fn routine_body_language(&self) -> &str
Returns the value of routine_body_language, or the default value if routine_body_language is unset.