pub struct ListFunctionsRequest {
pub catalog_name: String,
pub schema_name: String,
pub max_results: Option<i32>,
pub page_token: Option<String>,
pub include_browse: Option<bool>,
}Expand description
List functions in a schema
Fields
catalog_name: StringName of parent catalog for functions of interest.
schema_name: StringParent schema of functions.
max_results: Option<i32>The maximum number of results per page that should be returned.
page_token: Option<String>Opaque pagination token to go to next page based on previous query.
include_browse: Option<bool>Whether to include functions in the response for which the principal can only access selective metadata for.
Implementations
Sourceimpl ListFunctionsRequest
impl ListFunctionsRequest
Sourcepub fn max_results(&self) -> i32
pub fn max_results(&self) -> i32
Returns the value of max_results, or the default value if max_results is unset.
Sourcepub fn page_token(&self) -> &str
pub fn page_token(&self) -> &str
Returns the value of page_token, or the default value if page_token is unset.
Sourcepub fn include_browse(&self) -> bool
pub fn include_browse(&self) -> bool
Returns the value of include_browse, or the default value if include_browse is unset.