#[repr(i32)]pub enum ModelVersionStatus {
MODEL_VERSION_STATUS_UNSPECIFIED = 0,
PENDING_REGISTRATION = 1,
FAILED_REGISTRATION = 2,
READY = 3,
}Expand description
The status of a model version, reflecting the lifecycle of its artifacts in external storage.
Variants
MODEL_VERSION_STATUS_UNSPECIFIED = 0
The status is not specified.
PENDING_REGISTRATION = 1
The client has not yet completely written all model artifacts to external storage. This is the initial status assigned on creation.
FAILED_REGISTRATION = 2
The client failed to write all model artifacts to external storage.
READY = 3
The client successfully wrote all model artifacts to external storage and the version has been finalized.
Implementations
Sourceimpl ModelVersionStatus
impl ModelVersionStatus
Sourcepub const ModelVersionStatusUnspecified: Self = Self::MODEL_VERSION_STATUS_UNSPECIFIED
pub const ModelVersionStatusUnspecified: Self = Self::MODEL_VERSION_STATUS_UNSPECIFIED
Idiomatic alias for Self::MODEL_VERSION_STATUS_UNSPECIFIED; Debug prints the variant name.
Sourcepub const PendingRegistration: Self = Self::PENDING_REGISTRATION
pub const PendingRegistration: Self = Self::PENDING_REGISTRATION
Idiomatic alias for Self::PENDING_REGISTRATION; Debug prints the variant name.
Sourcepub const FailedRegistration: Self = Self::FAILED_REGISTRATION
pub const FailedRegistration: Self = Self::FAILED_REGISTRATION
Idiomatic alias for Self::FAILED_REGISTRATION; Debug prints the variant name.
Sourcepub const Ready: Self = Self::READY
pub const Ready: Self = Self::READY
Idiomatic alias for Self::READY; Debug prints the variant name.