pub struct Catalog {Show 15 fields
pub name: String,
pub id: Option<String>,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub storage_root: Option<String>,
pub provider_name: Option<String>,
pub share_name: Option<String>,
pub catalog_type: Option<i32>,
pub storage_location: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub browse_only: Option<bool>,
}Expand description
A catalog is a root-level namespace that contains schemas.
Fields
name: StringName of catalog.
id: Option<String>Unique identifier for the catalog.
owner: Option<String>Username of current owner of catalog.
comment: Option<String>User-provided free-form text description.
properties: HashMap<String, String>A map of key-value properties attached to the securable.
storage_root: Option<String>Storage root URL for managed tables within catalog.
provider_name: Option<String>The name of delta sharing provider.
A Delta Sharing catalog is a catalog that is based on a Delta share on a remote sharing server.
The name of the share under the share provider.
catalog_type: Option<i32>The type of the catalog.
storage_location: Option<String>Storage location URL (full path) for managed storage of the catalog.
A unique path under storage_root, used as the managed-storage parent for
managed tables/volumes whose schema has no storage location of its own.
Absent when the catalog has no storage_root.
Example: s3://bucket/ucroot/__unitystorage/catalogs/{catalog_id}.
created_at: Option<i64>Time at which this catalog was created, in epoch milliseconds.
created_by: Option<String>Username of catalog creator.
updated_at: Option<i64>Time at which this catalog was last updated, in epoch milliseconds.
updated_by: Option<String>Username of user who last modified catalog.
browse_only: Option<bool>Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.
Implementations
Sourceimpl Catalog
impl Catalog
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Catalog
impl Catalog
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn storage_root(&self) -> &str
pub fn storage_root(&self) -> &str
Returns the value of storage_root, or the default value if storage_root is unset.
Sourcepub fn provider_name(&self) -> &str
pub fn provider_name(&self) -> &str
Returns the value of provider_name, or the default value if provider_name is unset.
Returns the value of share_name, or the default value if share_name is unset.
Sourcepub fn catalog_type(&self) -> CatalogType
pub fn catalog_type(&self) -> CatalogType
Returns the enum value of catalog_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_catalog_type(&mut self, value: CatalogType)
pub fn set_catalog_type(&mut self, value: CatalogType)
Sets catalog_type to the provided enum value.
Sourcepub fn storage_location(&self) -> &str
pub fn storage_location(&self) -> &str
Returns the value of storage_location, or the default value if storage_location is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.
Sourcepub fn browse_only(&self) -> bool
pub fn browse_only(&self) -> bool
Returns the value of browse_only, or the default value if browse_only is unset.