ExternalLocation

Struct ExternalLocation 

pub struct ExternalLocation {
Show 13 fields pub name: String, pub url: String, pub credential_name: String, pub read_only: bool, pub comment: Option<String>, pub owner: Option<String>, pub credential_id: String, pub created_at: Option<i64>, pub created_by: Option<String>, pub updated_at: Option<i64>, pub updated_by: Option<String>, pub browse_only: Option<bool>, pub external_location_id: Option<String>,
}

Fields

name: String

Name of the external location.

url: String

Path URL of the external location.

credential_name: String

Name of the storage credential used with this location.

read_only: bool

Indicates whether the external location is read-only.

comment: Option<String>

User-provided free-form text description.

owner: Option<String>

The owner of the external location.

credential_id: String

Unique ID of the location’s storage credential.

created_at: Option<i64>

Time at which this catalog was created, in epoch milliseconds.

created_by: Option<String>

Username of catalog creator.

updated_at: Option<i64>

Time at which this catalog was last updated, in epoch milliseconds.

updated_by: Option<String>

Username of user who last modified catalog.

browse_only: Option<bool>

Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.

external_location_id: Option<String>

Implementations

Source

impl ExternalLocation

pub fn qualified_name(&self) -> String

Returns the fully-qualified dot-separated name computed from component fields.

Source

impl ExternalLocation

pub fn comment(&self) -> &str

Returns the value of comment, or the default value if comment is unset.

pub fn owner(&self) -> &str

Returns the value of owner, or the default value if owner is unset.

pub fn created_at(&self) -> i64

Returns the value of created_at, or the default value if created_at is unset.

pub fn created_by(&self) -> &str

Returns the value of created_by, or the default value if created_by is unset.

pub fn updated_at(&self) -> i64

Returns the value of updated_at, or the default value if updated_at is unset.

pub fn updated_by(&self) -> &str

Returns the value of updated_by, or the default value if updated_by is unset.

pub fn browse_only(&self) -> bool

Returns the value of browse_only, or the default value if browse_only is unset.

pub fn external_location_id(&self) -> &str

Returns the value of external_location_id, or the default value if external_location_id is unset.