pub struct Provider {
pub id: Option<String>,
pub name: String,
pub authentication_type: i32,
pub owner: Option<String>,
pub comment: Option<String>,
pub recipient_profile_str: Option<String>,
pub properties: HashMap<String, String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
}Expand description
A provider represents an organization sharing data with this metastore.
A provider is the inbound counterpart of a recipient: it is registered from a share activation/credential file and is used to access shares offered by an upstream Delta Sharing server.
Fields
id: Option<String>Unique ID of the provider.
name: StringThe name of the provider.
authentication_type: i32The delta sharing authentication type.
owner: Option<String>Username of the provider owner.
comment: Option<String>Description about the provider.
recipient_profile_str: Option<String>The recipient profile (credential file contents) used to connect to the sharing server, present only for TOKEN authentication.
properties: HashMap<String, String>A map of key-value properties attached to the provider.
created_at: Option<i64>Time at which this provider was created, in epoch milliseconds.
created_by: Option<String>Username of the creator of the provider.
updated_at: Option<i64>Time at which this provider was updated, in epoch milliseconds.
updated_by: Option<String>Username of the provider updater.
Implementations
Sourceimpl Provider
impl Provider
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Provider
impl Provider
Sourcepub fn authentication_type(&self) -> ProviderAuthenticationType
pub fn authentication_type(&self) -> ProviderAuthenticationType
Returns the enum value of authentication_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_authentication_type(&mut self, value: ProviderAuthenticationType)
pub fn set_authentication_type(&mut self, value: ProviderAuthenticationType)
Sets authentication_type to the provided enum value.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn recipient_profile_str(&self) -> &str
pub fn recipient_profile_str(&self) -> &str
Returns the value of recipient_profile_str, or the default value if recipient_profile_str is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.