pub struct Recipient {
pub id: Option<String>,
pub name: String,
pub authentication_type: i32,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub tokens: Vec<RecipientToken>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
}Fields
id: Option<String>Unique ID of the recipient.
name: StringThe name of the recipient.
authentication_type: i32The delta sharing authentication type.
owner: Option<String>Username of the recipient owner.
comment: Option<String>Description about the recipient.
properties: HashMap<String, String>A map of key-value properties attached to the securable.
created_at: Option<i64>Time at which this share was created, in epoch milliseconds.
created_by: Option<String>Username of the creator of the share.
tokens: Vec<RecipientToken>This field is only present when the authentication_type is TOKEN.
updated_at: Option<i64>Time at which this share was updated, in epoch milliseconds.
updated_by: Option<String>Username of share updater.
Implementations
Sourceimpl Recipient
impl Recipient
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Recipient
impl Recipient
Sourcepub fn authentication_type(&self) -> AuthenticationType
pub fn authentication_type(&self) -> AuthenticationType
Returns the enum value of authentication_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_authentication_type(&mut self, value: AuthenticationType)
pub fn set_authentication_type(&mut self, value: AuthenticationType)
Sets authentication_type to the provided enum value.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.