pub struct Share {
pub id: Option<String>,
pub name: String,
pub objects: Vec<DataObject>,
pub owner: Option<String>,
pub comment: Option<String>,
pub storage_location: Option<String>,
pub storage_root: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
/* private fields */
}Fields
id: Option<String>Unique ID of the recipient.
Field 100: id
name: StringName of the share.
Field 1: name
objects: Vec<DataObject>A list of shared data objects within the share.
Field 6: objects
owner: Option<String>Username of current owner of share.
Field 2: owner
comment: Option<String>User-provided free-form text description.
Field 3: comment
storage_location: Option<String>Storage Location URL (full path) for the share.
Field 4: storage_location
storage_root: Option<String>Storage root URL for the share.
Field 5: storage_root
created_at: Option<i64>Time at which this share was created, in epoch milliseconds.
Field 7: created_at
created_by: Option<String>Username of the creator of the share.
Field 8: created_by
updated_at: Option<i64>Time at which this share was updated, in epoch milliseconds.
Field 9: updated_at
updated_by: Option<String>Username of share updater.
Field 10: updated_by
Implementations
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourcepub fn with_id(self, value: impl Into<String>) -> Self
pub fn with_id(self, value: impl Into<String>) -> Self
Sets Self::id to Some(value), consuming and returning self.
Sourcepub fn with_owner(self, value: impl Into<String>) -> Self
pub fn with_owner(self, value: impl Into<String>) -> Self
Sets Self::owner to Some(value), consuming and returning self.
Sourcepub fn with_comment(self, value: impl Into<String>) -> Self
pub fn with_comment(self, value: impl Into<String>) -> Self
Sets Self::comment to Some(value), consuming and returning self.
Sourcepub fn with_storage_location(self, value: impl Into<String>) -> Self
pub fn with_storage_location(self, value: impl Into<String>) -> Self
Sets Self::storage_location to Some(value), consuming and returning self.
Sourcepub fn with_storage_root(self, value: impl Into<String>) -> Self
pub fn with_storage_root(self, value: impl Into<String>) -> Self
Sets Self::storage_root to Some(value), consuming and returning self.
Sourcepub fn with_created_at(self, value: i64) -> Self
pub fn with_created_at(self, value: i64) -> Self
Sets Self::created_at to Some(value), consuming and returning self.
Sourcepub fn with_created_by(self, value: impl Into<String>) -> Self
pub fn with_created_by(self, value: impl Into<String>) -> Self
Sets Self::created_by to Some(value), consuming and returning self.
Sourcepub fn with_updated_at(self, value: i64) -> Self
pub fn with_updated_at(self, value: i64) -> Self
Sets Self::updated_at to Some(value), consuming and returning self.
Sourcepub fn with_updated_by(self, value: impl Into<String>) -> Self
pub fn with_updated_by(self, value: impl Into<String>) -> Self
Sets Self::updated_by to Some(value), consuming and returning self.