pub struct Share {
pub id: Option<String>,
pub name: String,
pub objects: Vec<DataObject>,
pub owner: Option<String>,
pub comment: Option<String>,
pub storage_location: Option<String>,
pub storage_root: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
}Fields
id: Option<String>Unique ID of the recipient.
name: StringName of the share.
objects: Vec<DataObject>A list of shared data objects within the share.
owner: Option<String>Username of current owner of share.
comment: Option<String>User-provided free-form text description.
storage_location: Option<String>Storage Location URL (full path) for the share.
storage_root: Option<String>Storage root URL for the share.
created_at: Option<i64>Time at which this share was created, in epoch milliseconds.
created_by: Option<String>Username of the creator of the share.
updated_at: Option<i64>Time at which this share was updated, in epoch milliseconds.
updated_by: Option<String>Username of share updater.
Implementations
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn storage_location(&self) -> &str
pub fn storage_location(&self) -> &str
Returns the value of storage_location, or the default value if storage_location is unset.
Sourcepub fn storage_root(&self) -> &str
pub fn storage_root(&self) -> &str
Returns the value of storage_root, or the default value if storage_root is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.