pub struct Table {Show 20 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub table_type: i32,
pub data_source_format: i32,
pub columns: Vec<Column>,
pub storage_location: Option<String>,
pub view_definition: Option<String>,
pub view_dependencies: Option<DependencyList>,
pub owner: Option<String>,
pub comment: Option<String>,
pub properties: HashMap<String, String>,
pub storage_credential_name: Option<String>,
pub full_name: String,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub deleted_at: Option<i64>,
pub table_id: Option<String>,
}Fields
name: StringName of table, relative to parent schema.
catalog_name: StringName of parent catalog.
schema_name: StringName of parent schema.
table_type: i32data_source_format: i32Data source format of the table.
columns: Vec<Column>The array of Column definitions of the table’s columns.
storage_location: Option<String>Storage root URL for table (for MANAGED, EXTERNAL tables)
view_definition: Option<String>Definition text for view-like table types (VIEW, MATERIALIZED_VIEW, STREAMING_TABLE, METRIC_VIEW). The format depends on the table type: SQL for views, YAML for metric views.
view_dependencies: Option<DependencyList>Tables and functions the view-like table reads. For metric views this is derived from the view_definition by the server (the definition is the single source of truth).
owner: Option<String>Username of current owner of table.
comment: Option<String>User-provided free-form text description.
properties: HashMap<String, String>A map of key-value properties attached to the securable.
storage_credential_name: Option<String>Name of the storage credential, when a storage credential is configured for use with this table.
full_name: StringFull name of table, in form of catalog_name.schema_name.table_name.
created_at: Option<i64>Time at which this table was created, in epoch milliseconds.
created_by: Option<String>Username of table creator.
updated_at: Option<i64>Time at which this table was last updated, in epoch milliseconds.
updated_by: Option<String>Username of user who last modified table.
deleted_at: Option<i64>Time at which this table was deleted, in epoch milliseconds. Field is omitted if table is not deleted.
table_id: Option<String>Unique identifier for the table.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Table
impl Table
Sourcepub fn table_type(&self) -> TableType
pub fn table_type(&self) -> TableType
Returns the enum value of table_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_table_type(&mut self, value: TableType)
pub fn set_table_type(&mut self, value: TableType)
Sets table_type to the provided enum value.
Sourcepub fn data_source_format(&self) -> DataSourceFormat
pub fn data_source_format(&self) -> DataSourceFormat
Returns the enum value of data_source_format, or the default if the field is set to an invalid enum value.
Sourcepub fn set_data_source_format(&mut self, value: DataSourceFormat)
pub fn set_data_source_format(&mut self, value: DataSourceFormat)
Sets data_source_format to the provided enum value.
Sourcepub fn storage_location(&self) -> &str
pub fn storage_location(&self) -> &str
Returns the value of storage_location, or the default value if storage_location is unset.
Sourcepub fn view_definition(&self) -> &str
pub fn view_definition(&self) -> &str
Returns the value of view_definition, or the default value if view_definition is unset.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn storage_credential_name(&self) -> &str
pub fn storage_credential_name(&self) -> &str
Returns the value of storage_credential_name, or the default value if storage_credential_name is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.
Sourcepub fn deleted_at(&self) -> i64
pub fn deleted_at(&self) -> i64
Returns the value of deleted_at, or the default value if deleted_at is unset.