pub struct Volume {Show 15 fields
pub name: String,
pub catalog_name: String,
pub schema_name: String,
pub full_name: String,
pub storage_location: String,
pub volume_id: String,
pub volume_type: i32,
pub owner: Option<String>,
pub comment: Option<String>,
pub created_at: Option<i64>,
pub created_by: Option<String>,
pub updated_at: Option<i64>,
pub updated_by: Option<String>,
pub browse_only: Option<bool>,
pub metastore_id: Option<String>,
}Fields
name: StringName of volume, relative to parent schema.
catalog_name: StringName of parent catalog.
schema_name: StringName of parent schema.
full_name: StringThe three-level (fully qualified) name of the volume
storage_location: StringThe storage location on the cloud
volume_id: StringThe unique identifier of the volume
volume_type: i32The type of the volume.
An external volume is located in the specified external location. A managed volume is located in the default location which is specified by the parent schema, or the parent catalog, or the Metastore.
owner: Option<String>Username of current owner of table.
comment: Option<String>User-provided free-form text description.
created_at: Option<i64>Time at which this catalog was created, in epoch milliseconds.
created_by: Option<String>Username of catalog creator.
updated_at: Option<i64>Time at which this catalog was last updated, in epoch milliseconds.
updated_by: Option<String>Username of user who last modified catalog.
browse_only: Option<bool>Indicates whether the principal is limited to retrieving metadata for the associated object through the BROWSE privilege when include_browse is enabled in the request.
metastore_id: Option<String>The unique identifier of the metastore
Implementations
Sourceimpl Volume
impl Volume
Sourcepub fn qualified_name(&self) -> String
pub fn qualified_name(&self) -> String
Returns the fully-qualified dot-separated name computed from component fields.
Sourceimpl Volume
impl Volume
Sourcepub fn volume_type(&self) -> VolumeType
pub fn volume_type(&self) -> VolumeType
Returns the enum value of volume_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_volume_type(&mut self, value: VolumeType)
pub fn set_volume_type(&mut self, value: VolumeType)
Sets volume_type to the provided enum value.
Sourcepub fn owner(&self) -> &str
pub fn owner(&self) -> &str
Returns the value of owner, or the default value if owner is unset.
Sourcepub fn comment(&self) -> &str
pub fn comment(&self) -> &str
Returns the value of comment, or the default value if comment is unset.
Sourcepub fn created_at(&self) -> i64
pub fn created_at(&self) -> i64
Returns the value of created_at, or the default value if created_at is unset.
Sourcepub fn created_by(&self) -> &str
pub fn created_by(&self) -> &str
Returns the value of created_by, or the default value if created_by is unset.
Sourcepub fn updated_at(&self) -> i64
pub fn updated_at(&self) -> i64
Returns the value of updated_at, or the default value if updated_at is unset.
Sourcepub fn updated_by(&self) -> &str
pub fn updated_by(&self) -> &str
Returns the value of updated_by, or the default value if updated_by is unset.
Sourcepub fn browse_only(&self) -> bool
pub fn browse_only(&self) -> bool
Returns the value of browse_only, or the default value if browse_only is unset.
Sourcepub fn metastore_id(&self) -> &str
pub fn metastore_id(&self) -> &str
Returns the value of metastore_id, or the default value if metastore_id is unset.