GenerateTemporaryPathCredentialsRequest

Struct GenerateTemporaryPathCredentialsRequest 

pub struct GenerateTemporaryPathCredentialsRequest {
    pub url: String,
    pub operation: i32,
    pub dry_run: Option<bool>,
}
Generate a new set of credentials for a path.

Fields

url: String

URL for path-based access.

operation: i32

The operation being performed on the path.

dry_run: Option<bool>

When set to true, the service will not validate that the generated credentials can perform write operations, therefore no new paths will be created and the response will not contain valid credentials. Defaults to false.

Implementations

Source

impl GenerateTemporaryPathCredentialsRequest

pub fn operation(&self) -> Operation

Returns the enum value of operation, or the default if the field is set to an invalid enum value.

pub fn set_operation(&mut self, value: Operation)

Sets operation to the provided enum value.

pub fn dry_run(&self) -> bool

Returns the value of dry_run, or the default value if dry_run is unset.