pub struct GenerateTemporaryPathCredentialsRequest {
pub url: String,
pub operation: i32,
pub dry_run: Option<bool>,
}Expand description
Generate a new set of credentials for a path.
Fields
url: StringURL for path-based access.
operation: i32The operation being performed on the path.
dry_run: Option<bool>When set to true, the service will not validate that the generated credentials can perform write operations, therefore no new paths will be created and the response will not contain valid credentials. Defaults to false.
Implementations
Sourceimpl GenerateTemporaryPathCredentialsRequest
impl GenerateTemporaryPathCredentialsRequest