pub trait ResourceExt {
// Required methods
fn resource_name(&self) -> ResourceName;
fn resource_ref(&self) -> ResourceRef;
fn resource_ident(&self) -> ResourceIdent;
}Required Methods
Sourcefn resource_name(&self) -> ResourceName
fn resource_name(&self) -> ResourceName
Get the name of the resource
Sourcefn resource_ref(&self) -> ResourceRef
fn resource_ref(&self) -> ResourceRef
Get the reference for the resource
Depending on the resource type, this may be a UUID or a name. If possible, implementations should prefer to use the UUID as it is globally unique. However not all resource-like objects have a UUID field, or the UUID field may be optional.
Sourcefn resource_ident(&self) -> ResourceIdent
fn resource_ident(&self) -> ResourceIdent
Get the ident for the resource
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".